import { select, csv, scaleLinear, max, scaleBand, axisBottom, axisLeft } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const yValue = d => d.pop;
  const xValue = d => d.country;
  const margin = {top: 20, right: 20, left: 90, bottom: 50};
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0]);
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.padding(0.05);
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g')
    .attr('transform', `translate(0, ${innerHeight})`)
  .call(axisBottom(xScale));
  
  g.append('g').call(axisLeft(yScale));
  
  g.selectAll('rect').data(data)
  .enter().append('rect')
  	.attr('x', d => xScale(xValue(d)))
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', xScale.bandwidth())
  	.attr('height', d => innerHeight - yScale(yValue(d)))
  	.attr('fill', 'orange')
  	.on('click', d => {console.log(d);});
}

csv('data.csv', (d) => {
  return {
    country: d.country,
    pop: +d.pop
  };
}).then(data => {
  render(data);
});